==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/FormatCsv.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.CharsetEncoding;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class FormatCsv extends GenericDPSObject {
    /**
     * FORMAT_CSV.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * FORMAT_CSV.CHARSET
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private CharsetEncoding charset;

    /**
     * FORMAT_CSV.LINIA_OPISOW
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean liniaOpisow;

    /**
     * FORMAT_CSV.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * FORMAT_CSV.SEPARATOR_POLA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String separatorPola;

    /**
     * FORMAT_CSV.SEPARATOR_WIERSZA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String separatorWiersza;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return FORMAT_CSV.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * FORMAT_CSV.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return FORMAT_CSV.CHARSET
     * @mbggenerated 2014-03-10 10:45:37
     */
    public CharsetEncoding getCharset() {
        return charset;
    }

    /**
     * FORMAT_CSV.CHARSET
     *
     * @param charset
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCharset(CharsetEncoding charset) {
        this.charset = charset;
    }

    /**
     * @return FORMAT_CSV.LINIA_OPISOW
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getLiniaOpisow() {
        return liniaOpisow;
    }

    /**
     * FORMAT_CSV.LINIA_OPISOW
     *
     * @param liniaOpisow
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLiniaOpisow(Boolean liniaOpisow) {
        this.liniaOpisow = liniaOpisow;
    }

    /**
     * @return FORMAT_CSV.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * FORMAT_CSV.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return FORMAT_CSV.SEPARATOR_POLA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSeparatorPola() {
        return separatorPola;
    }

    /**
     * FORMAT_CSV.SEPARATOR_POLA
     *
     * @param separatorPola
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSeparatorPola(String separatorPola) {
        this.separatorPola = separatorPola == null ? null : separatorPola.trim();
    }

    /**
     * @return FORMAT_CSV.SEPARATOR_WIERSZA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSeparatorWiersza() {
        return separatorWiersza;
    }

    /**
     * FORMAT_CSV.SEPARATOR_WIERSZA
     *
     * @param separatorWiersza
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSeparatorWiersza(String separatorWiersza) {
        this.separatorWiersza = separatorWiersza == null ? null : separatorWiersza.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        FormatCsv other = (FormatCsv) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getCharset() == null ? other.getCharset() == null : this.getCharset().equals(other.getCharset()))
            && (this.getLiniaOpisow() == null ? other.getLiniaOpisow() == null : this.getLiniaOpisow().equals(other.getLiniaOpisow()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getSeparatorPola() == null ? other.getSeparatorPola() == null : this.getSeparatorPola().equals(other.getSeparatorPola()))
            && (this.getSeparatorWiersza() == null ? other.getSeparatorWiersza() == null : this.getSeparatorWiersza().equals(other.getSeparatorWiersza()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getCharset() == null) ? 0 : getCharset().hashCode());
        result = prime * result + ((getLiniaOpisow() == null) ? 0 : getLiniaOpisow().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getSeparatorPola() == null) ? 0 : getSeparatorPola().hashCode());
        result = prime * result + ((getSeparatorWiersza() == null) ? 0 : getSeparatorWiersza().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", charset=").append(charset);
        sb.append(", liniaOpisow=").append(liniaOpisow);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", separatorPola=").append(separatorPola);
        sb.append(", separatorWiersza=").append(separatorWiersza);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/FormatCsv.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.CharsetEncoding;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class FormatCsv extends GenericDPSObject {
    /**
     * FORMAT_CSV.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * FORMAT_CSV.CHARSET
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private CharsetEncoding charset;

    /**
     * FORMAT_CSV.LINIA_OPISOW
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean liniaOpisow;

    /**
     * FORMAT_CSV.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * FORMAT_CSV.SEPARATOR_POLA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String separatorPola;

    /**
     * FORMAT_CSV.SEPARATOR_WIERSZA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String separatorWiersza;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return FORMAT_CSV.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * FORMAT_CSV.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return FORMAT_CSV.CHARSET
     * @mbggenerated 2014-03-13 16:02:38
     */
    public CharsetEncoding getCharset() {
        return charset;
    }

    /**
     * FORMAT_CSV.CHARSET
     *
     * @param charset
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCharset(CharsetEncoding charset) {
        this.charset = charset;
    }

    /**
     * @return FORMAT_CSV.LINIA_OPISOW
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getLiniaOpisow() {
        return liniaOpisow;
    }

    /**
     * FORMAT_CSV.LINIA_OPISOW
     *
     * @param liniaOpisow
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLiniaOpisow(Boolean liniaOpisow) {
        this.liniaOpisow = liniaOpisow;
    }

    /**
     * @return FORMAT_CSV.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * FORMAT_CSV.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return FORMAT_CSV.SEPARATOR_POLA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSeparatorPola() {
        return separatorPola;
    }

    /**
     * FORMAT_CSV.SEPARATOR_POLA
     *
     * @param separatorPola
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSeparatorPola(String separatorPola) {
        this.separatorPola = separatorPola == null ? null : separatorPola.trim();
    }

    /**
     * @return FORMAT_CSV.SEPARATOR_WIERSZA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSeparatorWiersza() {
        return separatorWiersza;
    }

    /**
     * FORMAT_CSV.SEPARATOR_WIERSZA
     *
     * @param separatorWiersza
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSeparatorWiersza(String separatorWiersza) {
        this.separatorWiersza = separatorWiersza == null ? null : separatorWiersza.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        FormatCsv other = (FormatCsv) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getCharset() == null ? other.getCharset() == null : this.getCharset().equals(other.getCharset()))
            && (this.getLiniaOpisow() == null ? other.getLiniaOpisow() == null : this.getLiniaOpisow().equals(other.getLiniaOpisow()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getSeparatorPola() == null ? other.getSeparatorPola() == null : this.getSeparatorPola().equals(other.getSeparatorPola()))
            && (this.getSeparatorWiersza() == null ? other.getSeparatorWiersza() == null : this.getSeparatorWiersza().equals(other.getSeparatorWiersza()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getCharset() == null) ? 0 : getCharset().hashCode());
        result = prime * result + ((getLiniaOpisow() == null) ? 0 : getLiniaOpisow().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getSeparatorPola() == null) ? 0 : getSeparatorPola().hashCode());
        result = prime * result + ((getSeparatorWiersza() == null) ? 0 : getSeparatorWiersza().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", charset=").append(charset);
        sb.append(", liniaOpisow=").append(liniaOpisow);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", separatorPola=").append(separatorPola);
        sb.append(", separatorWiersza=").append(separatorWiersza);
        sb.append("]");
        return sb.toString();
    }
}
